#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: libexif-gtk
# PROJECT HOMEPAGE 	: http://libexif.sourceforge.net/
# SOURCES          	: http://downloads.sourceforge.net/libexif/
#
# AUTHOR         	: skywatcher (skywatcher|AT|netsons|DOT|org, simone antoniucci)
# LATEST REVISION	: 2008-02-04

### Checking for unbound variables
set -u

### Setting main variables
NAME="libexif-gtk"
VERSION="0.3.5"
ARCH="i486"
CPU="i686"
BUILD=52.1

HOMEPAGE="http://libexif.sourceforge.net/"
DESCRIPTION="gtk library for libexif"
SRCLNK="http://downloads.sourceforge.net/libexif/$NAME-$VERSION.tar.bz2"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=$NAME-$VERSION.tar.bz2
TAROPT="xvjf"
SRCDIR=$CWD/$NAME-$VERSION

BASE=http://users.zenwalk.org/user-accounts/skywatcher/$NAME

PATCH=libexif-gtk-gtk2.patch
PATCHLNK=$BASE/$PATCH

DOCS="ABOUT-NLS AUTHORS ChangeLog COPYING INSTALL NEWS README"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Checking if patch is present. If it's not, download it
if [ -f $PATCH ]; then
	echo "Patch is already present, no need to download it";
else
 	echo "Downloading patch..."
	wget -c -nv $PATCHLNK
fi

### Extracting source
tar $TAROPT $SRCPKG

### Patch
cd $SRCDIR/libexif-gtk
patch Makefile.in $CWD/$PATCH || exit 1
cp -a $CWD/$PATCH $PKGDIR/usr/src/$NAME-$VERSION 

### Configure, make, install
cd $SRCDIR
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
find $PKGDIR/usr/man -type f -exec gzip -9 {} \;

### Adding build-file and other stuff to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
cp -a $CWD/$PATCH $PKGDIR/usr/src/$NAME-$VERSION

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: libexif-gtk is a library of GTK+ based graphical user interface 
$NAME: elements for libexif.
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5sum and dep
cd $CWD
md5sum $PKG.tgz > $PKG.md5
requiredbuilder -z $PKG.tgz > $PKG.dep

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Ending it all
echo "To install type:"
echo "installpkg $PKG.tgz"
echo "To upgrade type:"
echo "upgradepkg $PKG.tgz"

### Done. Ciao!
